#!/bin/bash

if [ -f '/usr/sbin/wildix_shell_tools' ]; then
	. /usr/sbin/wildix_shell_tools
else
	logger -t "${0}" "ERROR: can't include wildix_shell_tools"
	exit 1
fi

CORES="$1" ; RAM="$2" ; AMAZON="$3" ; DOCKER="$4"

if [ -z $CORES ] || [ -z $RAM ] || [ -z $AMAZON ] || [ -z $DOCKER ]; then
	log "ERROR: zero values (exit)" "${0##*/}"
	exit 0
fi

__DISABLE_SWAP(){

	if [ -f /root/swapfile ]; then
		log "Cleaning up swap-file for PBX with more than 512M RAM." "${0##*/}"
		systemctl stop root-swapfile.swap
		systemctl disable root-swapfile.swap
		rm -f /root/swapfile
	fi	

}

## for cloud instances
if [ "$AMAZON" = "1" ]; then

	if [ "$RAM" -le "500" ]; then
		## set buffer pools to minimal possible value
		buffer_size=8M
		max_con=15

		## swap file creation for nano instances
		if [ ! -f /root/swapfile ]; then
			log "Creating swap-file for PBX with less than 512M RAM." "${0##*/}"
			fallocate -l 512M /root/swapfile
			chmod 0600 /root/swapfile
			mkswap /root/swapfile
		fi

		## swap unit file for automatic activation
		if [ ! -s "/etc/systemd/system/root-swapfile.swap" ]; then
			cat << END > /etc/systemd/system/root-swapfile.swap
[Unit]
Description=Swap for nano instances

[Swap]
What=/root/swapfile

[Install]
WantedBy=multi-user.target
END
		fi
		
		[[ "$(systemctl is-enabled root-swapfile.swap)" != "enabled" ]] && systemctl enable --now /etc/systemd/system/root-swapfile.swap

	elif [ "$RAM" -le "1000" ]; then
		buffer_size=32M
		max_con=15
		__DISABLE_SWAP
	elif [ "$RAM" -le "2000" ]; then
		buffer_size=128M
		max_con=50
		__DISABLE_SWAP
	elif [ "$RAM" -le "4000" ]; then
		buffer_size=128M
		max_con=100
		__DISABLE_SWAP
	else
		buffer_size=128M
		max_con=200
		__DISABLE_SWAP
	fi

	## alter mysql buffers
	if [ -d "/etc/mysql/mariadb.conf.d" ]; then
		cat << END > /etc/mysql/mariadb.conf.d/50-override.cnf
[mysqld]
innodb_buffer_pool_size = ${buffer_size}
max_connections = ${max_con}
innodb_flush_method = O_DIRECT
wait_timeout = 300
interactive_timeout = 300
END
	fi

	## disable remote support monit rule
	[ -f '/etc/monit/openvpn.conf' ] && sed -i '/^#/!s/\(.*\)/#\1/g' /etc/monit/openvpn.conf
	
	## disable remote support for all aws cloud !
	if [ "$(awk -F '=' '{print $2}' /rw2/etc/pbx/remote_support.config)" == "1" ]; then
		log "Disable remote support for aws cloud." "${0##*/}"
		echo "autostart=0" > /rw2/etc/pbx/remote_support.config
		systemctl stop openvpn@wildixclient.service
		systemctl disable openvpn@wildixclient.service
		systemctl disable openvpn
	fi

	## disable snmp for all aws clouds
	if [ "$(systemctl is-enabled snmpd)" == "enabled" ]; then
		log "Disable snmpd for aws cloud." "${0##*/}"
		systemctl stop snmpd || true
		systemctl disable snmpd
	fi

	## disable smartd for all aws clouds
	if [ "$(systemctl is-enabled smartd)" == "enabled" ]; then
		log "Disable smartd for aws cloud." "${0##*/}"
		systemctl stop smartd || true
		systemctl disable smartd
	fi

	## changing directory for mysql tmp dir
	MYSQL_CFG='/etc/mysql/mariadb.conf.d/50-server.cnf'
	MYSQL_TMP_DIR='/var/log/mysql'

	if [ -s "$MYSQL_CFG" ] && [ "$(awk '/^tmpdir.*=/{print $3}' $MYSQL_CFG)" != "$MYSQL_TMP_DIR" ]; then
		sed -i -e "/^tmpdir.*=/ s/=.*/= $(sed 's/\//\\\//g' <<< $MYSQL_TMP_DIR)/" $MYSQL_CFG
	fi
fi
